Imports VncSharp
Imports System.Windows.Forms

Public Class VncClientExampleForm
    ' Some times you might want to define your own function for the 
    ' password handler.  Here's how you do it (see the ctor below for more):
    '
    ' Private Shared Function GetPassword() As String
    '     ' Do your database/file/etc. work here and return a password
    '     Return "vncsharp"
    ' End Function

    Public Sub New()
        InitializeComponent()

        ' NOTE: if you want to add your own delegate for the password
        ' handler, you do it here (see static GetPassword() function above).
        ' rd.GetPassword = New AuthenticateDelegate(AddressOf GetPassword)
    End Sub

    Private Sub FlipMenuOptions()
        ConnectToolStripMenuItem.Enabled = Not rd.IsConnected

        DisconnectToolStripMenuItem.Enabled = rd.IsConnected
        CTRLALTDELToolStripMenuItem.Enabled = rd.IsConnected
        FullScreenRefreshToolStripMenuItem.Enabled = rd.IsConnected
        ALTF4ToolStripMenuItem.Enabled = rd.IsConnected
        CTRLESCToolStripMenuItem.Enabled = rd.IsConnected
        CTRLToolStripMenuItem.Enabled = rd.IsConnected
        ALTToolStripMenuItem.Enabled = rd.IsConnected
        CopyClipboardContentsToolStripMenuItem.Enabled = rd.IsConnected
    End Sub

    Private Sub ConnectToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ConnectToolStripMenuItem.Click
        ' Get a host name from the user.
        Dim host As String = ConnectDialog.GetVncHost()

        ' As long as they didn't click Cancel, try to connect
        If (Not host = Nothing) Then
            Try
                rd.Connect(host, ViewOnlyToolStripMenuItem.Checked, ScaledViewToolStripMenuItem.Checked)
            Catch vex As VncProtocolException
                MessageBox.Show(Me, _
                                String.Format("Unable to connect to VNC host: {0}.  Check that a VNC host is running there.", vex.Message), _
                                String.Format("Unable to Connect to {0}", host), _
                                MessageBoxButtons.OK, _
                                MessageBoxIcon.Exclamation)
            Catch ex As Exception
                MessageBox.Show(Me, _
                                String.Format("Unable to connect to host.  Error was: {0}", ex.Message), _
                                String.Format("Unable to Connect to {0}", host), _
                                MessageBoxButtons.OK, _
                                MessageBoxIcon.Exclamation)
            End Try
        End If
    End Sub

    Private Sub DisconnectToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles DisconnectToolStripMenuItem.Click
        If (rd.IsConnected) Then
            rd.Disconnect()
        End If
    End Sub

    Private Sub ClippedViewToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ClippedViewToolStripMenuItem.Click
        ClippedViewToolStripMenuItem.Checked = True
        ScaledViewToolStripMenuItem.Checked = False

        ' Turn-off scaling and use clipping
        If (rd.IsConnected) Then
            rd.SetScalingMode(False)
        End If
    End Sub

    Private Sub ScaledViewToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ScaledViewToolStripMenuItem.Click
        ClippedViewToolStripMenuItem.Checked = False
        ScaledViewToolStripMenuItem.Checked = True

        ' Turn-off clipping and use scaling
        If (rd.IsConnected) Then
            rd.SetScalingMode(True)
        End If
    End Sub

    Private Sub FullScreenRefreshToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles FullScreenRefreshToolStripMenuItem.Click
        ' Request a fullscreen update (normally incremental updates are sent)
        If (rd.IsConnected) Then
            rd.FullScreenUpdate()
        End If
    End Sub

    Private Sub ViewOnlyToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ViewOnlyToolStripMenuItem.Click
        ViewOnlyToolStripMenuItem.Checked = Not ViewOnlyToolStripMenuItem.Checked

        ' Turn view-only mode (no mouse/keyboard events sent) on or off
        If (rd.IsConnected) Then
            rd.SetInputMode(ViewOnlyToolStripMenuItem.Checked)
        End If
    End Sub

    Private Sub CopyClipboardContentsToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CopyClipboardContentsToolStripMenuItem.Click
        ' Copy the contents of the local clipboard into the server's clipboard
        ' so that it can be pasted.  Only works with text.
        If (rd.IsConnected) Then
            rd.FillServerClipboard()

            MessageBox.Show(Me, _
                            "Your clipboard's text was copied to the remote host.", _
                            "Clipboard Copied", _
                            MessageBoxButtons.OK, _
                            MessageBoxIcon.Information)
        End If
    End Sub

    Private Sub CTRLALTDELToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CTRLALTDELToolStripMenuItem.Click
        If (rd.IsConnected) Then
            rd.SendSpecialKeys(SpecialKeys.CtrlAltDel)
        End If
    End Sub

    Private Sub ALTF4ToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ALTF4ToolStripMenuItem.Click
        If (rd.IsConnected) Then
            rd.SendSpecialKeys(SpecialKeys.AltF4)
        End If
    End Sub

    Private Sub CTRLESCToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CTRLESCToolStripMenuItem.Click
        If (rd.IsConnected) Then
            rd.SendSpecialKeys(SpecialKeys.CtrlEsc)
        End If
    End Sub

    Private Sub CTRLToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CTRLToolStripMenuItem.Click
        If (rd.IsConnected) Then
            rd.SendSpecialKeys(SpecialKeys.Ctrl, False) ' Don't release CTRL
        End If
    End Sub

    Private Sub ALTToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ALTToolStripMenuItem.Click
        If (rd.IsConnected) Then
            rd.SendSpecialKeys(SpecialKeys.Alt, False) ' Don't release ALT
        End If
    End Sub

    Private Sub VncClientExampleForm_FormClosing(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles MyBase.FormClosing
        ' If the user tries to close the window without doing a clean
        ' shutdown of the remote connection, do it for them.
        If (rd.IsConnected) Then
            rd.Disconnect()
        End If
    End Sub

    Private Sub rd_ConnectComplete(ByVal sender As System.Object, ByVal e As VncSharp.ConnectEventArgs) Handles rd.ConnectComplete
        ' Update the Form to match the geometry of remote desktop, including the height of the menu bar.
        ClientSize = New Size(e.DesktopWidth, e.DesktopHeight + MenuStrip1.Height)

        ' Change the Form's title to match the remote desktop name
        Text = e.DesktopName

        ' Give the remote desktop focus now that it's connected.
        rd.Focus()

        FlipMenuOptions()
    End Sub

    Private Sub rd_ConnectionLost(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles rd.ConnectionLost
        ' Let the user know of the lost connection
        MessageBox.Show(Me, _
                        "Lost Connection to Host.", _
                        "Connection Lost", _
                        MessageBoxButtons.OK, _
                        MessageBoxIcon.Information)
        FlipMenuOptions()
    End Sub

    Private Sub rd_ClipboardChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles rd.ClipboardChanged
        ' You normally wouldn't do this (i.e., you might show something in the status bar),
        ' but as a demo, let the user know that there is new data in the local clipboard
        MessageBox.Show(Me, _
                        "Remote clipboard copied to local host.", _
                        "Clipboard Changed", _
                        MessageBoxButtons.OK, _
                        MessageBoxIcon.Information)
    End Sub
End Class